@@ -13,8 +13,8 @@ proto <- function (. = parent.env(envir), expr = {}, envir =
 
 as.proto <- function(x, ...) UseMethod("as.proto")
 as.proto.environment <- function(x, ...) {
-	assign("that", x, x)
-	assign("super", parent.env(x), x)
+	assign(".that", x, x)
+	assign(".super", parent.env(x), x)
 	structure(x, class = c("proto", "environment"))
 }
 as.proto.proto <- function(x, ...) x
@@ -33,14 +33,14 @@ as.proto.list <- function(x, envir, parent, FUN = function(x) TRUE,
              if (is.function(x[[s]])) environment(envir[[s]]) <- envir
           }
        if (!missing(parent)) parent.env(envir) <- parent
-       as.proto.environment(envir)  # force refresh of that and super
+       as.proto.environment(envir)  # force refresh of .that and .super
 }
 
 "$.proto" <- function(this, x) {
    inh <- substr(x,1,2) != ".."
    p <- parent.frame()
    is.function <- is.function(get(x, this, inherits = inh))
-   is.that <- match(deparse(substitute(this)), c("that","super"), nomatch=0)
+   is.that <- match(deparse(substitute(this)), c(".that",".super"), nomatch=0)
    s <- if (is.function && !is.that)
          substitute(function(...) get(x, this, inherits = inh)(this, ...))
    else
@@ -51,7 +51,7 @@ as.proto.list <- function(x, envir, parent, FUN = function(x) TRUE,
 }
 
 "$<-.proto" <- function(this,s,value) { 
-        if (s == "super") parent.env(this) <- value
+        if (s == ".super") parent.env(this) <- value
 	if (is.function(value))  environment(value) <- this
 	this[[as.character(substitute(s))]] <- value
 	this
